# MaLeSMo - Machine Learning Standard Models

Python package with wrappers for standart machine learning models

## Installation

To install the package from PyPI type:

```
pip install malesmo
```

Or from the repo:

```
pip install git+https://github.com/loven-doo/MaLeSMo.git
```

For 'dev' branch version:

```
pip install git+https://github.com/loven-doo/MaLeSMo.git@dev
```

## Package reference

### gboost

